
#ifndef _C15_li726_
#define _C15_li726_

#ifdef __cplusplus
extern "C" {
#endif

extern void F146_2141(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit726(void);
extern long O2109[];

#ifdef __cplusplus
}
#endif

#endif
